"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.envSrcSsm = exports.envSrcJson = exports.envSrc = void 0;
const fs_1 = require("fs");
const { readFile } = fs_1.promises;
let ssm;
async function envSrc(options) {
    const options_ = Array.prototype.concat(options);
    const tasks = options_.reduce((tasks, option) => {
        Object.keys(option).map((type) => {
            if (type === 'json') {
                tasks.push(envSrcJson(option.json));
            }
            else if (type === 'ssm') {
                tasks.push(envSrcSsm(option.ssm));
            }
            else {
                throw new Error(`Unknown source type '${type}'`);
            }
        });
        return tasks;
    }, []);
    await Promise.all(tasks);
}
exports.envSrc = envSrc;
function applyEnv(env) {
    Object.keys(env).forEach(key => {
        if (process.env[key] === undefined) {
            process.env[key] = env[key];
        }
    });
}
async function envSrcJson(options) {
    const data = await readFile(options.path, 'utf8');
    applyEnv(JSON.parse(data));
}
exports.envSrcJson = envSrcJson;
async function envSrcSsm(options) {
    ssm || (ssm = new (require('aws-sdk')).SSM());
    const params = {
        Path: options.path,
        Recursive: options.recursive,
        WithDecryption: options.withDecryption,
    };
    const data = await ssm.getParametersByPath(params).promise();
    const { Parameters } = data;
    if (!Parameters) {
        return;
    }
    const env = Parameters.reduce((env, { Name, Value }) => {
        Name = Name.substr(options.path.length + 1).replace('/', '_');
        env[Name] = Value;
        return env;
    }, {});
    applyEnv(env);
}
exports.envSrcSsm = envSrcSsm;
